import os
import shutil
import uvicore
from ohmyi3 import i3ctl
from ohmyi3.util import path
from uvicore.support.dumper import dump, dd
from uvicore.exceptions import SmartException
from uvicore.console import command, argument, option

@command()
async def cli():
    """Initialize a stock ~/.config/ohmyi3/* configuration"""

    # Get the user config
    config_path = path(uvicore.config('ohmyi3.config_path'))
    app_path = path(uvicore.app.package(main=True).path, True)
    stubs_path = path([app_path, 'stubs'], True)

    uvicore.log.header(f'Initializing ohmyi3 to {config_path}')

    # Create ~/.config/ohmyi3/ and copy stubs
    if not os.path.exists(config_path):
        uvicore.log.item(f"Creating {config_path} folder")
        uvicore.log.item(f"Copying base configs into {config_path} folder")
        shutil.copytree(stubs_path, config_path)

    # Get the user config
    config = i3ctl.import_userconfig().config()

    # Get i3 and i3status path
    i3_path = config.paths.i3 if config.paths.i3 else path('~/.config/i3')
    i3status_path = config.paths.i3status if config.paths.i3status else path('~/.config/i3status')

    # Create ~/.config/i3
    if not os.path.exists(i3_path):
        uvicore.log.item(f"Creating {i3_path} folder")
        os.mkdir(i3_path)

    # Create ~/.config/i3status
    if not os.path.exists(i3status_path):
        uvicore.log.item(f"Creating {i3status_path} folder")
        os.mkdir(i3status_path)

    uvicore.log.nl()
    uvicore.log('Done!  Now run: i3ctl generate')



import uvicore
from uvicore.support.dumper import dump, dd
from ohmyi3.util import path, exists, template

class Alacritty:
    """
    Ohmyi3 Alacritty Terminal Plugin
    Copyright (c) 2023 Matthew Reschke License http://mreschke.com/license/mit
    """

    def __init__(self, config):
        """Instantiate Plugin with User Configuration"""
        self.config = config

    def template_config(self):
        """Template the alacritty.yml config"""
        base = self.config.paths.alacritty
        j2_yml = path([base, 'alacritty.j2.yml'])
        yml = path([base, 'alacritty.yml'])

        # Log output
        uvicore.log.item4(f'Plugin Alacritty: Templating {j2_yml}')

        # Validation
        if not exists(j2_yml):
            uvicore.log.error(f'Cannot find {j2_yml}')
            return

        # Write template
        template(j2_yml, output=yml, values=self.config)




import uvicore
from uvicore.configuration import Env
from uvicore.support import path
from uvicore.support.dumper import dd, dump


def application(is_console: bool = False) -> None:
    """Bootstrap the application either from the CLI or Web entry points

    Bootstrap only runs when this package is running as the main app via
    ./uvicore or uvicorn/gunicorn server"""

    # Base path
    base_path = path.find_base(__file__)

    # Load .env from environs
    Env().read_env(base_path + '/.env')

    # Import this apps config (import must be after Env())
    from ..config.app import config as app_config

    # Bootstrap the Uvicore Application (Either CLI or HTTP entry points based on is_console)
    uvicore.bootstrap(app_config, base_path, is_console)

    # Return application
    return uvicore.app



import uvicore
from uvicore.support.dumper import dump, dd
from ohmyi3.util import path, exists, shell

class Nitrogen:
    """
    Ohmyi3 Nitrogen Wallpaper Plugin
    Copyright (c) 2023 Matthew Reschke License http://mreschke.com/license/mit
    """

    def __init__(self, config):
        """Instantiate Plugin with User Configuration"""
        self.config = config

    def set_wallpaper(self):
        """Set nitrogen wallpaper based on selected theme"""
        theme = self.config.theme
        themes = self.config.themes
        themes_path = self.config.paths.ohmyi3_themes
        wallpaper_base = self.config.wallpaper_base

        # Get theme background file (jpg or png)
        background = None
        theme_path = path([self.config.paths.ohmyi3_themes, self.config.theme])
        jpg = path([theme_path, 'background.jpg'])
        png = path([theme_path, 'background.jpg'])
        if exists(jpg): background = jpg
        if exists(png): background = png

        # Check for background override
        override = themes.dotget(f"{theme}.wallpaper")
        if override: background = path(f"{wallpaper_base}/{override}")

        # If no theme background file or override found, don't set background
        if not background: return

        # If background found, set it using nitrogen
        if exists(background):
            cmd = f"nitrogen --save --set-zoom-fill {background} > /dev/null 2>&1"
            #cmd = f"nitrogen --save --set-scaled {background} > /dev/null 2>&1"
            uvicore.log.item4(f"Plugin Nitrogen: {cmd}")
            shell(cmd)



import uvicore
from ohmyi3 import util
from uvicore.typing import Dict
from uvicore.configuration import env
from uvicore.support.dumper import dump, dd
from ohmyi3.util import Overridable, gather, path, plugin

# Settings and hooks for ohmyi3 i3ctl config generator.
# Configs as python gives unlimited flexibility and programability.
# All of these self.* variables are accessible as jinja2 variables
# to dynamically control your i3 configs and anything else that
# requires automation (see the plugins)

def config():
    """Ohmyi3 variables for configuring and templating i3"""

    # Hostname and user from system
    host = util.hostname()
    user = util.loggedinuser()

    # Refresh overridables with all local variables thus far
    set = Overridable(**locals())

    # Paths to all relevant locations
    # If you need to change the ohmyi3 path, use the
    # environment variable OHMYI3_PATH (default ~/.config/ohmyi3)
    ohmyi3_path = uvicore.config('ohmyi3.config_path')
    paths = set({
        'ohmyi3': path(ohmyi3_path),
        'ohmyi3_configd': path([ohmyi3_path, 'config.d']),
        'ohmyi3_themes': path([ohmyi3_path, 'themes']),
        'i3': path('~/.config/i3'),
        'i3status': path('~/.config/i3status'),
        'alacritty': path('~/.config/alacritty'),
        'polybar': path('~/.config/polybar'),
    })

    # OS variant
    os = set('manjaro', if_host={
        'p14s': 'lmde'
    })

    # Main network interface
    net_interface = set('enp11s0', if_host={
        'p15': 'enp11s0',
        'p53': 'wlp0s20f3',
        'deajaro': 'wlp2s0',
    })

    # Has battery (laptop?)
    has_battery = set(True, if_host={
        'sunjaro': False,
        'p53': True,
        'p15': True,
        'p14s': True,
    })
    battery_device = set('BAT0')

    # Backlinght
    backlight_device = set('intel_backlight')

    # Desktop Environment (kde, xfce, i3, cinnamon, mate, gnome)
    # I like to run i3 inside kde and xfce etc...  If runing under these DE's
    # I need to tweak the configs (no screen lock, different autostarts etc...)
    desktop = set('i3', if_host={
        'sunjaro': 'kde',
        'p53': 'i3',
        'p15': 'i3',
        #'p14s': 'cinnamon',
    })

    # Main desktop tools (kde, xfce...)
    # Not the same as desktop, which is the running Desktop Environment
    desktop_tools = set('kde', if_host={
        'deajaro': 'xfce'
    })

    # Using i3 capable of gaps
    i3_gaps = set(True, if_host={
        'p14s': False
    })

    # Restart i3 command
    i3_restart = set('~/.files/scripts/i3ctl-dev generate && i3-msg restart', if_host={
        'deajaro': 'i3ctl generate && i3-msg restart',
    })

    # Wallpaper base
    wallpaper_base = set('~/Wallpaper', if_host={
        'sunjaro': '~/Pictures/Wallpaper',
        'p53': '~/Pictures/Wallpaper',
    })

    # Current theme (amber, archlinux, manjaro, pink)
    theme = set('manjaro', if_host={
        'sunjaro': 'manjaro',
        'p53': 'manjaro',
        'p15': 'pink',
        'p14s': 'manjaro',
    })

    # Refresh overridables with all local variables thus far
    set = Overridable(**locals())

    # Extra theme details
    # Wallpaper is an OVERRIDE, else defaults to the themes folder/background.[jpg|png]
    themes = set({
        'amber': {
            #'wallpaper': 'Abstract/cracked_orange.jpg',
            #'wallpaper': 'Manjaro/antelope-canyon-984055.jpg',
            #'wallpaper': 'Scenes/digital_sunset.jpg',
            #'wallpaper': 'LinuxMint/linuxmint-vera/mpiwnicki_red_dusk.jpg',
            #'wallpaper': 'LinuxMint/linuxmint-vanessa/navi_india.jpg',
            'wallpaper': 'LinuxMint/linuxmint-una/nwatson_eclipse.jpg',
            #'wallpaper': 'LinuxMint/linuxmint-vera/navi_india.jpg',
            #'wallpaper': 'LinuxMint/linuxmint-ulyssa/tangerine_nanpu.jpg',
            #'wallpaper': 'Manjaro/sky-3189347.jpg',
            'archey3': 'yellow',
        },
        'archlinux': {
            #'wallpaper': 'Archlinux/349880.jpg',
            'archey3': 'blue',
            'wallpaper': 'De/budgie.jpg',
        },
        'manjaro': {
            #'wallpaper': 'Manjaro/illyria-default-lockscreen-nobrand.jpg',
            #'wallpaper': 'Manjaro/wpM_orbit2_textured.jpg'
            'wallpaper': 'De/deepin.jpg',
            'archey3': 'green',
        },
        'pink': {
            #'wallpaper': 'Abstract/artistic_colors2.jpg',
            #'wallpaper': 'Landscape/backlit-chiemsee-dawn-1363876.jpg',
            #`'wallpaper': 'Manjaro/DigitalMilkyway.png',
            #'wallpaper': 'LinuxMint/linuxmint-una/eeselioglu_istanbul.jpg',
            #'wallpaper': 'Abstract/neon_huawei.jpg',
            'wallpaper': 'De/budgie.jpg',
            'archey3': 'magenta',
        },
    },
        if_host={
            #'p15': {'manjaro.wallpaper': 'Manjaro/wpM_orbit2_textured.jpg'}
            'p15': {'manjaro.wallpaper': 'De/deepin.jpg'}
        }
    )

    # Polybar
    # Specific to the custom qpanel theme made from this https://github.com/adi1090x/polybar-themes
    polybar = set({
        'enabled': True,
        # blocks|colorblocks|cuts|docky|forest|grayblocks|hack|material
        # panels|pwidgets|qpanels|shades|shapes
        'theme': 'qpanels',
        # budgie|deepin|elight|edark|gnomw|klight|kdark
        # liri|mint|ugnome|unity|xubuntu|zorin
        'subtheme': 'deepin'
    }, if_host={
        'p14s': {'polybar.enabled': False},
    })

    # Rofi
    rofi = set({
        'launcher': f'~/.config/polybar/{polybar.theme}/scripts/launcher.sh --{polybar.subtheme}',
        'powermenu': f'~/.config/polybar/{polybar.theme}/scripts/powermenu.sh --{polybar.subtheme}',
    },
        if_host={
            'p14s': {'launcher': 'rofi -show drun'}
        }
    )

    # Alacritty
    alacritty = set({
        'font_size': '10.0',
    }, if_host={
        'p15': {'font_size': '8.0'}
    })

    # Default font for window titles (not bar.font)
    font = set('xft:URWGothic-Book 9')

    # i3bar configs
    # All themes may obey these global bar configs, or they may set their own
    bar = set({
        'enabled': False,
        #'cmd': 'i3bar',
        'cmd': 'i3bar --transparency',
        'status_cmd': 'i3status',
        'position': 'bottom',
        'font': 'xft:URWGothic-Book 8',

        # Hide or show the bar
        'mode': 'dock', # dock|hide|invisible
        'hidden_state': 'hide', # hide|show

        # Modifier makes the hidden bar show up while key is pressed
        'modifier': 'none',
        #'modifier': 'Ctrl+$alt',
    },
        # FIXME, make an ifnot_desktop == i3
        if_desktop={
            'kde': {'mode': 'hide'}
        },
        if_hostname={
            'p15': {'position': 'top'},
            'p14s': {'enabled': True},
        },
    )

    # Preferred applications, could change depending on DE installed
    apps = set({
        'terminal': 'alacritty',
        'filemanager': 'dolphin',
        'webbrowser': 'firefox',
        'webbrowser2': 'chromium',
        'calculator': 'kcalc',
        'settings': 'systemsettings',
        'screenshot': 'spectacle', # i3-scrot
        'dmenu': path('~/.files/scripts/dmenu-run-blue'),
        'screenlock': 'blurlock',
        'powermanager': 'xfce4-power-manager',
        'powermanagersettings': 'xfce4-power-manager-settings',
        'xsslock': f'xss-lock -- blurlock',
        #'xsslock': f'xss-lock -- i3lock --nofork --image {wallpaper_base}/De/deepin.jpg',
        'networkeditor': 'nm-connection-editor',
        'htop': 'htop',
        'bashtop': 'bashtop',
        'taskmanager': 'ksysguard',
        'codeeditor': 'code',
        'notepad': 'kate',
        'colorpicker': 'kcolorchooser',
        'spotify': 'spotify',
        'clipboard': 'clipit --daemon',
    },
        if_theme={
            'manjaro': {'dmenu': path('~/.files/scripts/dmenu-run-green')}
        },
        if_host={
            'p14s': {
                'terminal': 'gnome-terminal',
                'calculator': 'gnome-calculator',
                'screenlock': 'i3lock',
            },
            'deajaro': {
                'filemanager': 'thunar',
                'calculator': 'xcalc',
                'taskmanager': 'xfce4-taskmanager',
                'settings': 'xfce4-settings-manager',
            },
        },
    )

    # Tray Icons
    tray = set({
        'volume': 'volumeicon',
        'network': 'nm-applet',
    })

    # Volume Control
    volume = set({
        'up': 'amixer -D pulse sset Master 5%+',
        'down': 'amixer -D pulse sset Master 5%-',
        'mute': 'amixer -D pulse set Master 1+ toggle',
        # Or self.terminal + '-e alsamixer'
        'mixer': 'pavucontrol'
    })

    # Media Control
    media = set({
        'play_pause': 'playerctl play-pause',
        'next': 'playerctl next',
        'previous': 'playerctl previous',
    })

    # Brightness Control
    brightness = set({
        'up': 'brightnessctl -q set 3%+',
        'down': 'brightnessctl --min-val=2 -q set 3%-',
    })

    # Dynamically Load and Instantiate Plugins
    # Pluging must be LAST after all variables are set
    _vars = gather(locals())
    plugins = set({
        'nitrogen': plugin('nitrogen.Nitrogen')(_vars),
        'archey3': plugin('archey3.Archey3')(_vars),
        'polybar': plugin('polybar.Polybar')(_vars),
        'alacritty': plugin('alacritty.Alacritty')(_vars),
    })

    # Return all variables to the ohmyi3 generator for templating
    return gather(locals())



async def before_generate(config):
    """This hook fires before the new i3 config is generated"""
    #dump('before hook')

async def after_generate(config):
    """This hook fires after the new i3 config is generated"""
    #dump('after hook')

    # Set themed wallpaper
    config.plugins.nitrogen.set_wallpaper()

    # Set themed archey in my .zshrc and or .bashrc
    config.plugins.archey3.set_archey()

    # Modify polybar theme files (template some variables)
    config.plugins.polybar.adjust_polybar()

    # Template the alacritty config
    config.plugins.alacritty.template_config()



import os
import platform
from uvicore.typing import Dict
from datetime import datetime
from uvicore.support.module import load
from jinja2 import Environment as JinjaEnv
from uvicore.support.dumper import dump, dd
from jinja2 import FileSystemLoader as JinjaLoader

def plugin(module, **kwargs):
    return load('plugins.' + module).object


def path(location, must_exist=False, notfound_message=None):
    """Path helper with realpath and expanduser capabilities"""
    if type(location) == list:
        # If location is a list, join together with /
        location = "/".join(location)

    # Get real expanded path
    real = os.path.realpath(os.path.expanduser(location))

    # If must_exist, ensure it exists or display a message and exit
    if must_exist:
        if not os.path.exists(real):
            print(f"{real} not found")
            if notfound_message: print(notfound_message)
            exit(1)

    # Return real expanded path
    return real


def exists(location):
    """Check if path exists, using path() helper for realpath and expanduser"""
    return os.path.exists(path(location))


def now(dateformat='%Y-%m-%d_%H-%M-%S'):
    """Get now() date time in specified format (defaults 2021-01-24_19-24-58)"""
    return datetime.now().strftime(dateformat)


def shell(cmd):
    """Execute a shell command"""
    return os.system(cmd)


def template(file, *, base=None, output=None, values=None) -> str:
    """Render a single file through the Jinja2 templating system, return or write output"""
    if not base: base = os.path.dirname(file)
    base = path(base)
    filename = os.path.basename(file)
    loader = JinjaLoader(searchpath=base)
    env = JinjaEnv(loader=loader)
    template = env.get_template(filename)
    rendered = template.render(values)
    if output:
        with open(output, 'w') as f:
            f.write(rendered)
    return rendered


def loggedinuser():
    return os.getlogin();


def hostname():
    return platform.node()


def gather(locals):
    """Gather variables that do not begin with _ or 'set' as a Superdict"""
    _variables = Dict()
    for key, value in locals.items():
        if key[0] != '_' and key != 'set':
            _variables[key] = value
    return _variables


class Overridable:
    """Store all locals() for further set() overridable commands"""

    def __init__(self, **kwargs):
        self.kwargs = kwargs

    def __call__(self, default, **kwargs):
        # If type of default is dict, convert to Superdict
        if type(default) == dict: default = Dict(default)

        # Loop each possible if_* override kwargs
        for override_key, override_value in kwargs.items():
            override_key = override_key[3:]

            # If type of override_value is dict, convert to Superdict
            if type(override_value) == dict: override_value = Dict(override_value)

            # If the override_key is found in our Overridable values
            if override_key in self.kwargs:
                # Get the override_keys value
                override_key_value = self.kwargs[override_key]

                # Loop our the passed in override_value for matching override_key_value
                for k, v in override_value.items():
                    if k == override_key_value:
                        if type(default) == Dict:
                            for findkey, newvalue in v.items():
                                #default.dotset(findkey, newvalue)
                                default.dotset(findkey, newvalue)
                                #v = default
                                #dd(v)
                            #return default
                        else:
                            default = v
        return default



import shutil
import uvicore
from uvicore.support.dumper import dump, dd
from ohmyi3.util import path, exists, shell, template

class Polybar:
    """
    Ohmyi3 Polybar Plugin
    Copyright (c) 2023 Matthew Reschke License http://mreschke.com/license/mit
    """

    def __init__(self, config):
        """Instantiate Plugin with User Configuration"""
        self.config = config

    def adjust_polybar(self):
        # Get polybar config
        polybar = self.config.polybar

        # If polybar not enabled, skip
        if not polybar.enabled: return

        # Polybar base path
        base = self.config.paths.polybar

        # Main running polybar config for this theme
        # Because the style switcher COPIES the config.ini into this main running ini
        running_ini = path([base, polybar.theme, 'config.ini'])

        # Get the themes panel folder
        panel_folder = path([base, polybar.theme, 'panel'])

        # Get the themes ini and template
        config_ini = path([panel_folder, polybar.subtheme + '.ini'])
        config_j2_ini = path([panel_folder, polybar.subtheme + '.j2.ini'])

        # Get the shared modules ini and template
        modules_ini = path([base, polybar.theme, 'modules.ini'])
        modules_j2_ini = path([base, polybar.theme, 'modules.j2.ini'])

        # Get the shared bars ini and template
        bars_ini = path([base, polybar.theme, 'bars.ini'])
        bars_j2_ini = path([base, polybar.theme, 'bars.j2.ini'])

        # Log output
        uvicore.log.item4(f'Plugin Polybar: Templating {config_j2_ini}')

        # Validation of .j2 file
        if not exists(config_j2_ini):
            uvicore.log.error(f'Cannot find {config_j2_ini}')
            return

        # Write config.ini from config.j2.ini
        template(config_j2_ini, output=config_ini, values=self.config)

        # Write modules.ini from modules.j2.ini
        template(modules_j2_ini, output=modules_ini, values=self.config)

        # Write bars.ini from bars.j2.ini
        template(bars_j2_ini, output=bars_ini, values=self.config)

        # Copy this templated config.ini to the main running_ini
        shutil.copy(config_ini, running_ini)



from uvicore.configuration import env
from uvicore.typing import OrderedDict

# This is the main ohmyi3 config.  All items here can be overridden
# when used inside other applications.  Accessible at config('ohmyi3')

config = {

    # --------------------------------------------------------------------------
    # Package Custom Configuration
    # --------------------------------------------------------------------------
    'config_path': env('OHMYI3_PATH', '~/.config/ohmyi3'),


    # --------------------------------------------------------------------------
    # Package Information
    #
    # Most other info like name, short_name, vendor are derived automatically
    # --------------------------------------------------------------------------
    'version': '0.1.0',


    # --------------------------------------------------------------------------
    # Registration Control
    # --------------------------------------------------------------------------
    # This lets you control the service provider registrations.  If this app
    # is used as a package inside another app you might not want some things
    # registered in that context.  Use config overrides in your app to change
    # registrations
    'registers': {
        'commands': True,
    },


    # --------------------------------------------------------------------------
    # Package Dependencies (Service Providers)
    #
    # Define all the packages that this package depends on.  At a minimum, only
    # the uvicore.foundation package is required.  The foundation is very
    # minimal and only depends on configuration, logging and console itself.
    # You must add other core services built into uvicore only if your package
    # requires them.  Services like uvicore.database, uvicore.orm, uvicore.auth
    # uvicore.http, etc...
    # --------------------------------------------------------------------------
    'dependencies': OrderedDict({
        # Foundation is the core of uvicore and is required as the first dependency.
        # Foundation itself relys on configuration, logging, console, cache and more.
        'uvicore.foundation': {
            'provider': 'uvicore.foundation.services.Foundation',
        },
    }),

}



import uvicore
from uvicore.support.dumper import dump, dd
from uvicore.exceptions import SmartException
from uvicore.console import command, argument, option

from ohmyi3 import i3ctl

@command()
async def cli():
    """Display ohmyi3 configuration information"""

    # Get the user config
    config = i3ctl.import_userconfig().config()

    uvicore.log.header("Ohmyi3 User Configuration")
    dump(config)




import os
import sys
import uvicore
from ohmyi3.util import path


def import_userconfig():
    """Dynamically import the users ~/.config/ohmyi3/configurator.py"""

    config_folder = path(uvicore.config('ohmyi3.config_path'), True,
        notfound_message="Perhpas you havent run 'i3ctl init' yet??")

    # App userconfig path to sys.path for imports
    sys.path.append(os.path.realpath(config_folder))
    import config
    return config





import os
import sys
import shutil
import uvicore
from glob import glob
from uvicore.typing import Dict
from ohmyi3.util import path, now, template
from uvicore.support.dumper import dump, dd
from uvicore.exceptions import SmartException

from uvicore.console import command, argument, option


from ohmyi3 import i3ctl


@command()
async def cli():
    """Dynamically Generate a new i3 config using Ohmyi3"""

    # Get the user config files
    userconfig = i3ctl.import_userconfig()

    # Get the actual user config Superdict
    config = userconfig.config()

    # Get ohmyi3 paths
    ohmyi3_path = uvicore.config('ohmyi3.config_path')
    ohmyi3_configd_path = config.paths.ohmyi3_configd
    ohmyi3_themes_path = config.paths.ohmyi3_themes

    # Start the generation
    uvicore.log.header("Generating new i3 config using ohmyi3")

    # Fire off user defined before_generate_hook
    uvicore.log.item3("Firing user defined before_generate hook")
    await userconfig.before_generate(config)

    # If i3 config exists, back it up
    i3config_file = f"{config.paths.i3}/config"
    if os.path.exists(i3config_file):
        backup = path([config.paths.i3, 'backup-' + now()])
        uvicore.log.item(f"Backing up {i3config_file} to {backup}")
        shutil.copy(i3config_file, backup)

    # Get all config.d/* files
    files = sorted(glob(ohmyi3_configd_path + "/*.conf"))

    # Get active theme path
    active_theme_path = f"{ohmyi3_themes_path}/{config.theme}"

    # Append config.d/* and theme.d/theme to new i3 config
    with open(i3config_file, "w") as f:
        # Loop and merge each config and append to
        for file in files:
            uvicore.log.item2(f"Appending {file}")
            f.write(template(file, values=config))
            f.write("\n\n\n")

        # Append the selected theme files
        theme_file = path([active_theme_path, 'theme.conf'])
        if os.path.exists(theme_file):
            uvicore.log.item(f"Appending THEME {config.theme}")
            f.write(template(theme_file, values=config))

    # Copy themed i3status or a default if no theme specific file exists
    i3status_template_path = None
    if os.path.exists(f"{active_theme_path}/i3status.conf"):
        # Use themed i3status.conf
        i3status_template_path = active_theme_path
    elif os.path.exists(f"{ohmyi3_themes_path}/i3status.conf"):
        # Use default i3status.conf
        i3status_template_path = f"{ohmyi3_themes_path}"

    if i3status_template_path:
        uvicore.log.item(f"Copying {i3status_template_path}/i3status.conf to {config.paths.i3status}/config")
        with open(f"{config.paths.i3status}/config", "w") as f:
            f.write(template('i3status.conf', base=i3status_template_path, values=config))

    # Fire off user defined afer_generate_hook
    uvicore.log.item3("Firing user defined after_generate hook")
    await userconfig.after_generate(config)

    # Cleanup __pycache__
    pycache = path([ohmyi3_path, '__pycache__'])
    if os.path.exists(pycache):
        shutil.rmtree(pycache)

    # Done
    uvicore.log.nl()
    uvicore.log("Done!")
    uvicore.log(f"New {i3config_file} generated!")
    uvicore.log("Please reload i3!")



import uvicore
from ohmyi3 import util
from uvicore.support.dumper import dump, dd

class Archey3:
    """
    Ohmyi3 Archey3 Plugin
    Copyright (c) 2023 Matthew Reschke License http://mreschke.com/license/mit
    """

    def __init__(self, config):
        """Instantiate Plugin with User Configuration"""
        self.config = config

    def set_archey(self):
        """Set ~/.zshrc archey3 color based on theme"""
        themes = self.config.themes
        theme = self.config.theme
        color = themes.dotget(f"{theme}.archey3")

        if not color: return
        if util.exists('~/.zshrc'):
            cmd = f"sed -i 's/archey3.*/archey3 -c {color}/g' ~/.zshrc"
            uvicore.log.item4(f"Plugin Archey3: {cmd}")
            util.shell(cmd)
        if util.exists('~/.bashrc'):
            cmd = f"sed -i 's/archey3.*/archey3 -c {color}/g' ~/.bashrc"
            uvicore.log.item4(f"Plugin Archey3: {cmd}")
            util.shell(cmd)
